Pocket TTS - Streaming

# Pocket TTS

Hello world. I am Kyutai's Pocket TTS. I'm fast enough to run on small CPUs. I hope you'll like me.
Optional voice URL (leave empty to use default voice):

Supports: http://, https://, or hf:// URLs.
You can also use predefined voices:
"alba", "marius", "javert", "jean", "fantine", "cosette", "eponine", "azelma".
You can find more voices in our voice repository.

Or upload an audio file for voice cloning:

Upload an audio file (WAV, MP3, FLAC, etc.) to use as voice reference. Takes precedence over voice URL. For best results, clean the sample first.

### Generated Audio

Download